==> hvcg_governance_openapi_catholic-polity-0.1.1.crate: hvcg_governance_openapi_catholic-polity-0.1.1/docs/diocese_api.md <==
# diocese_api

All URIs are relative to *http://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**addDiocese**](diocese_api.md#addDiocese) | **POST** /mutation-api/dioceses | Add new diocese
**deleteDiocese**](diocese_api.md#deleteDiocese) | **DELETE** /mutation-api/deanery/{id} | Delete diocese by ID
**getAllDioceses**](diocese_api.md#getAllDioceses) | **GET** /query-api/dioceses | Get all dioceses
**getDioceseById**](diocese_api.md#getDioceseById) | **GET** /query-api/diocese/{id} | Find diocese by ID
**updateDiocese**](diocese_api.md#updateDiocese) | **PUT** /mutation-api/diocese/{id} | Update an existing diocese


# **addDiocese**
> models::Diocese addDiocese(ctx, diocese)
Add new diocese

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **diocese** | [**Diocese**](Diocese.md)| Diocese object that needs to be added to the database | 

### Return type

[**models::Diocese**](Diocese.md)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteDiocese**
> deleteDiocese(ctx, id)
Delete diocese by ID

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| ID of diocese that needs to be deleted | 

### Return type

 (empty response body)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getAllDioceses**
> models::Diocese getAllDioceses(ctx, optional)
Get all dioceses

Returns all dioceses

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
 **optional** | **map[string]interface{}** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a map[string]interface{}.

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **province** | [****](.md)|  | 
 **name** | **String**|  | 

### Return type

[**models::Diocese**](Diocese.md)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getDioceseById**
> models::Diocese getDioceseById(ctx, id)
Find diocese by ID

Returns a single diocese

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| ID of diocese to return | 

### Return type

[**models::Diocese**](Diocese.md)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateDiocese**
> models::Parish updateDiocese(ctx, id, diocese)
Update an existing diocese

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| ID of diocese to update | 
  **diocese** | [**Diocese**](Diocese.md)| Diocese object that needs to be added to the database | 

### Return type

[**models::Parish**](Parish.md)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> hvcg_governance_openapi_catholic-polity-0.1.3.crate: hvcg_governance_openapi_catholic-polity-0.1.3/docs/diocese_api.md <==
# diocese_api

All URIs are relative to *http://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**add_diocese**](diocese_api.md#add_diocese) | **POST** /mutation-api/dioceses | Add new diocese
**delete_diocese**](diocese_api.md#delete_diocese) | **DELETE** /mutation-api/deanery | Delete diocese by ID
**get_diocese_by_id**](diocese_api.md#get_diocese_by_id) | **GET** /query-api/dioceses/{id} | Find diocese by ID
**get_dioceses**](diocese_api.md#get_dioceses) | **GET** /query-api/dioceses | Get all dioceses
**update_diocese**](diocese_api.md#update_diocese) | **PUT** /mutation-api/diocese | Update an existing diocese


# **add_diocese**
> models::Diocese add_diocese(ctx, diocese)
Add new diocese

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **diocese** | [**Diocese**](Diocese.md)| Diocese object that needs to be added to the database | 

### Return type

[**models::Diocese**](Diocese.md)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_diocese**
> delete_diocese(ctx, )
Delete diocese by ID

### Required Parameters
This endpoint does not need any parameter.

### Return type

 (empty response body)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_diocese_by_id**
> models::Diocese get_diocese_by_id(ctx, id)
Find diocese by ID

Returns a single diocese

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| ID of diocese to return | 

### Return type

[**models::Diocese**](Diocese.md)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_dioceses**
> models::Diocese get_dioceses(ctx, optional)
Get all dioceses

Returns all dioceses

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
 **optional** | **map[string]interface{}** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a map[string]interface{}.

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **province_name** | **String**|  | 
 **name** | **String**|  | 

### Return type

[**models::Diocese**](Diocese.md)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_diocese**
> models::Parish update_diocese(ctx, diocese)
Update an existing diocese

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **diocese** | [**Diocese**](Diocese.md)| Diocese object that needs to be added to the database | 

### Return type

[**models::Parish**](Parish.md)

### Authorization

[polity_auth](../README.md#polity_auth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
